Documentation
¶
Overview ¶
Package account provides the /v1/accounts APIs
Index ¶
- func Del(id string, params *stripe.AccountParams) (*stripe.Account, error)
- func Get() (*stripe.Account, error)
- func GetByID(id string, params *stripe.AccountParams) (*stripe.Account, error)
- func New(params *stripe.AccountParams) (*stripe.Account, error)
- func Reject(id string, params *stripe.AccountRejectParams) (*stripe.Account, error)
- func Update(id string, params *stripe.AccountParams) (*stripe.Account, error)
- type Client
- func (c Client) Del(id string, params *stripe.AccountParams) (*stripe.Account, error)deprecated
- func (c Client) Get() (*stripe.Account, error)
- func (c Client) GetByID(id string, params *stripe.AccountParams) (*stripe.Account, error)deprecated
- func (c Client) List(listParams *stripe.AccountListParams) *Iterdeprecated
- func (c Client) New(params *stripe.AccountParams) (*stripe.Account, error)deprecated
- func (c Client) Reject(id string, params *stripe.AccountRejectParams) (*stripe.Account, error)deprecated
- func (c Client) Update(id string, params *stripe.AccountParams) (*stripe.Account, error)deprecated
- type Iter
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Del ¶
With [Connect](https://docs.stripe.com/connect), you can delete accounts you manage.
Test-mode accounts can be deleted at any time.
Live-mode accounts that have access to the standard dashboard and Stripe is responsible for negative account balances cannot be deleted, which includes Standard accounts. All other Live-mode accounts, can be deleted when all [balances](https://docs.stripe.com/api/balance/balance_object) are zero.
If you want to delete your own account, use the [account information tab in your account settings](https://dashboard.stripe.com/settings/account) instead.
func New ¶
func New(params *stripe.AccountParams) (*stripe.Account, error)
With [Connect](https://docs.stripe.com/docs/connect), you can create Stripe accounts for your users. To do this, you'll first need to [register your platform](https://dashboard.stripe.com/account/applications/settings).
If you've already collected information for your connected accounts, you [can prefill that information](https://docs.stripe.com/docs/connect/best-practices#onboarding) when creating the account. Connect Onboarding won't ask for the prefilled information during account onboarding. You can prefill any information on the account.
func Reject ¶
With [Connect](https://docs.stripe.com/connect), you can reject accounts that you have flagged as suspicious.
Only accounts where your platform is liable for negative account balances, which includes Custom and Express accounts, can be rejected. Test-mode accounts can be rejected at any time. Live-mode accounts can only be rejected after all balances are zero.
func Update ¶
Updates a [connected account](https://docs.stripe.com/connect/accounts) by setting the values of the parameters passed. Any parameters not provided are left unchanged.
For accounts where [controller.requirement_collection](https://docs.stripe.com/api/accounts/object#account_object-controller-requirement_collection) is application, which includes Custom accounts, you can update any information on the account.
For accounts where [controller.requirement_collection](https://docs.stripe.com/api/accounts/object#account_object-controller-requirement_collection) is stripe, which includes Standard and Express accounts, you can update all information until you create an [Account Link or <a href="/api/account_sessions">Account Session](https://docs.stripe.com/api/account_links) to start Connect onboarding, after which some properties can no longer be updated.
To update your own account, use the [Dashboard](https://dashboard.stripe.com/settings/account). Refer to our [Connect](https://docs.stripe.com/docs/connect/updating-accounts) documentation to learn more about updating accounts.
Types ¶
type Client ¶
Client is used to invoke /v1/accounts APIs. Deprecated: Use stripe.Client instead. See the migration guide for more info.
func (Client) Del
deprecated
With [Connect](https://docs.stripe.com/connect), you can delete accounts you manage.
Test-mode accounts can be deleted at any time.
Live-mode accounts that have access to the standard dashboard and Stripe is responsible for negative account balances cannot be deleted, which includes Standard accounts. All other Live-mode accounts, can be deleted when all [balances](https://docs.stripe.com/api/balance/balance_object) are zero.
If you want to delete your own account, use the [account information tab in your account settings](https://dashboard.stripe.com/settings/account) instead.
Deprecated: Client methods are deprecated. This should be accessed instead through stripe.Client. See the migration guide for more info.
func (Client) GetByID
deprecated
Retrieves the details of an account.
Deprecated: Client methods are deprecated. This should be accessed instead through stripe.Client. See the migration guide for more info.
func (Client) List
deprecated
func (c Client) List(listParams *stripe.AccountListParams) *Iter
Returns a list of accounts connected to your platform via [Connect](https://docs.stripe.com/docs/connect). If you're not a platform, the list is empty.
Deprecated: Client methods are deprecated. This should be accessed instead through stripe.Client. See the migration guide for more info.
func (Client) New
deprecated
With [Connect](https://docs.stripe.com/docs/connect), you can create Stripe accounts for your users. To do this, you'll first need to [register your platform](https://dashboard.stripe.com/account/applications/settings).
If you've already collected information for your connected accounts, you [can prefill that information](https://docs.stripe.com/docs/connect/best-practices#onboarding) when creating the account. Connect Onboarding won't ask for the prefilled information during account onboarding. You can prefill any information on the account.
Deprecated: Client methods are deprecated. This should be accessed instead through stripe.Client. See the migration guide for more info.
func (Client) Reject
deprecated
With [Connect](https://docs.stripe.com/connect), you can reject accounts that you have flagged as suspicious.
Only accounts where your platform is liable for negative account balances, which includes Custom and Express accounts, can be rejected. Test-mode accounts can be rejected at any time. Live-mode accounts can only be rejected after all balances are zero.
Deprecated: Client methods are deprecated. This should be accessed instead through stripe.Client. See the migration guide for more info.
func (Client) Update
deprecated
Updates a [connected account](https://docs.stripe.com/connect/accounts) by setting the values of the parameters passed. Any parameters not provided are left unchanged.
For accounts where [controller.requirement_collection](https://docs.stripe.com/api/accounts/object#account_object-controller-requirement_collection) is application, which includes Custom accounts, you can update any information on the account.
For accounts where [controller.requirement_collection](https://docs.stripe.com/api/accounts/object#account_object-controller-requirement_collection) is stripe, which includes Standard and Express accounts, you can update all information until you create an [Account Link or <a href="/api/account_sessions">Account Session](https://docs.stripe.com/api/account_links) to start Connect onboarding, after which some properties can no longer be updated.
To update your own account, use the [Dashboard](https://dashboard.stripe.com/settings/account). Refer to our [Connect](https://docs.stripe.com/docs/connect/updating-accounts) documentation to learn more about updating accounts.
Deprecated: Client methods are deprecated. This should be accessed instead through stripe.Client. See the migration guide for more info.
type Iter ¶
Iter is an iterator for accounts.
func List ¶
func List(params *stripe.AccountListParams) *Iter
Returns a list of accounts connected to your platform via [Connect](https://docs.stripe.com/docs/connect). If you're not a platform, the list is empty.
func (*Iter) AccountList ¶
func (i *Iter) AccountList() *stripe.AccountList
AccountList returns the current list object which the iterator is currently using. List objects will change as new API calls are made to continue pagination.