Documentation
¶
Overview ¶
Package shippingrate provides the /v1/shipping_rates APIs
Index ¶
- func Get(id string, params *stripe.ShippingRateParams) (*stripe.ShippingRate, error)
- func New(params *stripe.ShippingRateParams) (*stripe.ShippingRate, error)
- func Update(id string, params *stripe.ShippingRateParams) (*stripe.ShippingRate, error)
- type Client
- func (c Client) Get(id string, params *stripe.ShippingRateParams) (*stripe.ShippingRate, error)deprecated
- func (c Client) List(listParams *stripe.ShippingRateListParams) *Iterdeprecated
- func (c Client) New(params *stripe.ShippingRateParams) (*stripe.ShippingRate, error)deprecated
- func (c Client) Update(id string, params *stripe.ShippingRateParams) (*stripe.ShippingRate, error)deprecated
- type Iter
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Get ¶
func Get(id string, params *stripe.ShippingRateParams) (*stripe.ShippingRate, error)
Returns the shipping rate object with the given ID.
func New ¶
func New(params *stripe.ShippingRateParams) (*stripe.ShippingRate, error)
Creates a new shipping rate object.
func Update ¶
func Update(id string, params *stripe.ShippingRateParams) (*stripe.ShippingRate, error)
Updates an existing shipping rate object.
Types ¶
type Client ¶
Client is used to invoke /v1/shipping_rates APIs. Deprecated: Use stripe.Client instead. See the migration guide for more info.
func (Client) Get
deprecated
func (c Client) Get(id string, params *stripe.ShippingRateParams) (*stripe.ShippingRate, error)
Returns the shipping rate object with the given ID.
Deprecated: Client methods are deprecated. This should be accessed instead through stripe.Client. See the migration guide for more info.
func (Client) List
deprecated
func (c Client) List(listParams *stripe.ShippingRateListParams) *Iter
Returns a list of your shipping rates.
Deprecated: Client methods are deprecated. This should be accessed instead through stripe.Client. See the migration guide for more info.
func (Client) New
deprecated
func (c Client) New(params *stripe.ShippingRateParams) (*stripe.ShippingRate, error)
Creates a new shipping rate object.
Deprecated: Client methods are deprecated. This should be accessed instead through stripe.Client. See the migration guide for more info.
func (Client) Update
deprecated
func (c Client) Update(id string, params *stripe.ShippingRateParams) (*stripe.ShippingRate, error)
Updates an existing shipping rate object.
Deprecated: Client methods are deprecated. This should be accessed instead through stripe.Client. See the migration guide for more info.
type Iter ¶
Iter is an iterator for shipping rates.
func List ¶
func List(params *stripe.ShippingRateListParams) *Iter
Returns a list of your shipping rates.
func (*Iter) ShippingRate ¶
func (i *Iter) ShippingRate() *stripe.ShippingRate
ShippingRate returns the shipping rate which the iterator is currently pointing to.
func (*Iter) ShippingRateList ¶
func (i *Iter) ShippingRateList() *stripe.ShippingRateList
ShippingRateList returns the current list object which the iterator is currently using. List objects will change as new API calls are made to continue pagination.